@@ -26,12 +26,12 @@ def where():
 
 def old_where():
     warnings.warn(
-        "The weak security bundle is being deprecated. It will be removed in "
-        "2018.",
+        "The weak security bundle has been removed. certifi.old_where() is now an alias "
+        "of certifi.where(). Please update your code to use certifi.where() instead. "
+        "certifi.old_where() will be removed in 2018.",
         DeprecatedBundleWarning
     )
-    f = os.path.dirname(__file__)
-    return os.path.join(f, 'weak.pem')
+    return where()
 
 if __name__ == '__main__':
     print(where())
